/*
 *   libdi - scsipt SCSI Device Interface Library
 *
 *   Copyright (C) 1993-2002  Ti Kan
 *   E-mail: xmcd@amb.org
 *
 *   This program is free software; you can redistribute it and/or modify
 *   it under the terms of the GNU General Public License as published by
 *   the Free Software Foundation; either version 2 of the License, or
 *   (at your option) any later version.
 *
 *   This program is distributed in the hope that it will be useful,
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *   GNU General Public License for more details.
 *
 *   You should have received a copy of the GNU General Public License
 *   along with this program; if not, write to the Free Software
 *   Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 */
#ifndef __OS_DEMO_H__
#define __OS_DEMO_H__

#if (defined(DI_SCSIPT) || defined(CDDA_RD_SCSIPT)) && defined(DEMO_ONLY)

#ifndef LINT
static char *_os_demo_h_ident_ = "@(#)os_demo.h	6.19 02/03/15";
#endif


#include "libdi_d/os_cdsim.h"	/* CD-ROM simulator header file */


/* Public function prototypes */
extern bool_t	pthru_send(int, byte_t *, int, byte_t *, int, byte_t,
			   int, bool_t);
extern int	pthru_open(char *);
extern void	pthru_close(int);
extern char	*pthru_vers(void);
extern bool_t	pthru_cdsim_start(void);
extern void	pthru_cdsim_stop(void);

#endif	/* DI_SCSIPT CDDA_RD_SCSIPT DEMO_ONLY */

#endif	/* __OS_DEMO_H__ */

